@@ -1,7 +1,7 @@
 import datetime
+import json
 import urllib.parse
 
-import bson
 import requests
 
 from django.core.cache import cache
@@ -17,6 +17,7 @@ from .settings import MB_AUTHENTICATIONS
 
 class AnonymousUser(object):
     id = None
+    uuid = None
     pk = id
     username = ''
     is_staff = False
@@ -161,7 +162,7 @@ class OAuth2Mixin(object):
         expires_in = min(300, expires_in)
         cache.set(
             self.make_access_cache_key(access_token),
-            bson.dumps(user),
+            json.dumps(user),
             expires_in,
         )
 
@@ -178,7 +179,7 @@ class OAuth2Mixin(object):
 
     def load_user_from_cache(self, access_token):
         data = cache.get(self.make_access_cache_key(access_token))
-        return data and bson.loads(data) or {}
+        return data and json.loads(data) or {}
 
     def do_get_introspect_token(self):
         response = requests.post(self.oauth2_login_url, data={
@@ -331,8 +332,10 @@ class BearerAuthentication(
 
     def authenticate_credentials(self, key):
         user = self.get_user_by_access_token(key)
-        return user and self.compose_user(
-            user, access_token=key), key or None
+        return user and (
+            self.compose_user(
+                user, access_token=key), key
+        ) or None
 
     def authenticate_header(self, request):
         return 'Bearer'
