@@ -1,3 +1,4 @@
+import collections
 import json
 import uuid
 
@@ -19,7 +20,7 @@ class AuthenticationMocker(Mocker):
         self.user_uuid = user_uuid or uuid.uuid4().hex
         self.user_scopes = (
             ' '.join(user_scopes) if
-            isinstance(user_scopes, (list, tuple)) else ''
+            isinstance(user_scopes, collections.Iterable) else ''
         )
         self.access_token = access_token or uuid.uuid4().hex
 
